PyQtGraph’s Graphics Items — pyqtgraph 0.11.0rc0 documentation

# PyQtGraph’s Graphics Items

Since pyqtgraph relies on Qt’s GraphicsView framework, most of its graphics functionality is implemented as QGraphicsItem subclasses. This has two important consequences: 1) virtually anything you want to draw can be easily accomplished using the functionality provided by Qt. 2) Many of pyqtgraph’s GraphicsItem classes can be used in any normal QGraphicsScene.

Contents:

- PlotDataItem
- PlotItem
- ImageItem
- GraphItem
- ViewBox
- LinearRegionItem
- InfiniteLine
- ROI
- GraphicsLayout
- PlotCurveItem
- ScatterPlotItem
- IsocurveItem
- AxisItem
- TextItem
- ErrorBarItem
- ArrowItem
- FillBetweenItem
- CurvePoint
- CurveArrow
- GridItem
- ScaleBar
- LabelItem
- VTickGroup
- LegendItem
- GradientEditorItem
- TickSliderItem
- HistogramLUTItem
- GradientLegend
- ButtonItem
- GraphicsObject
- GraphicsWidget
- GraphicsItem
- UIGraphicsItem
- GraphicsWidgetAnchor